@@ -1,6 +1,6 @@
 <?php declare(strict_types=1);
 
-namespace DeepCopyTest\Matcher;
+namespace DeepCopyTest\Matcher\Doctrine;
 
 use BadMethodCallException;
 use DeepCopy\Matcher\Doctrine\DoctrineProxyMatcher;
